@@ -1,4 +1,5 @@
 import os
+import logging
 
 from express.properties import BaseProperty
 from express.properties.scalar.p_norm import PNorm
@@ -12,6 +13,7 @@ from express.properties.scalar.elemental_ratio import ElementalRatio
 from express.properties.structural.inchi import Inchi
 from express.properties.structural.inchi_key import InchiKey
 from express.parsers.molecule import MoleculeParser
+from express.parsers.crystal import CrystalParser
 
 class Material(BaseProperty):
     """
@@ -20,8 +22,9 @@ class Material(BaseProperty):
 
     def __init__(self, name, parser, *args, **kwargs):
         super(Material, self).__init__(name, parser, *args, **kwargs)
+        self.is_non_periodic = kwargs.get("is_non_periodic", False)
 
-        cell = kwargs.get("cell", "original")
+        cell_type = kwargs.get("cell_type", "original")
         structure_string = kwargs.get("structure_string")
         structure_format = kwargs.get("structure_format", "poscar")
 
@@ -44,9 +47,10 @@ class Material(BaseProperty):
                     lattice = self.parser.final_lattice_vectors()
                     structure_string = lattice_basis_to_poscar(lattice, basis)
 
-        # override parser to use StructureParser from now on
-        self.parser = StructureParser(structure_string=structure_string, structure_format=structure_format, cell=cell)
-        self.molecule_parser = MoleculeParser(structure_string=structure_string)
+        if self.is_non_periodic == False:
+            self.parser = CrystalParser(structure_string=structure_string, structure_format=structure_format, cell_type=cell_type)
+        else:
+            self.parser = MoleculeParser(structure_string=structure_string, structure_format=structure_format, cell_type=cell_type)
 
     @property
     def formula(self):
@@ -60,15 +64,24 @@ class Material(BaseProperty):
     def derived_properties(self):
         derived_properties = []
         try:
-            inchi = Inchi("inchi", self.molecule_parser).serialize_and_validate()
-            inchi_key = InchiKey("inchi_key", self.molecule_parser).serialize_and_validate()
-            volume = Volume("volume", self.parser).serialize_and_validate()
-            density = Density("density", self.parser).serialize_and_validate()
             symmetry = Symmetry("symmetry", self.parser).serialize_and_validate()
-            derived_properties = [volume, density, symmetry, inchi, inchi_key]
+            if self.is_non_periodic:
+                inchi = Inchi("inchi", self.parser).serialize_and_validate()
+                inchi_key = InchiKey("inchi_key", self.parser).serialize_and_validate()
+                volume = None
+                density = None
+                derived_properties = [symmetry, inchi, inchi_key]
+            else:
+                inchi = None
+                inchi_key = None
+                volume = Volume("volume", self.parser).serialize_and_validate()
+                density = Density("density", self.parser).serialize_and_validate()
+                derived_properties = [volume, density, symmetry]
             derived_properties.extend(self._elemental_ratios())
             derived_properties.extend(self._p_norms())
+        # TODO: Determine how to avoid an eternal pass when one derived property fails
         except:
+            logging.info("Derived properties array empty due to failure to caluclate one (or more) values.")
             pass
         return derived_properties
 
