@@ -1647,16 +1647,24 @@ SI = {
         "slug": ""
     },
     "derivedProperties": [
-        {
-            "name": "volume",
-            "units": "angstrom^3",
-            "value": 40.88909038874689
-        },
         {
             "name": "density",
             "units": "g/cm^3",
             "value": 2.2811497523923894
         },
+        {
+            "name": "inchi",
+            "value": ""
+        },
+        {
+            "name": "inchi_key",
+            "value": ""
+        },
+        {
+            "name": "volume",
+            "units": "angstrom^3",
+            "value": 40.88909038874689
+        },
         {
             "name": "symmetry",
             "spaceGroupSymbol": "Fd-3m",
